==> humhub-1.11.0-beta.2.tar.gz: humhub-1.11.0-beta.2/protected/humhub/modules/admin/messages/zh-TW/settings.php <==
<?php

return [
    'Save' => '儲存',
    '1 month' => '',
    '1 week' => '',
    '1 year' => '',
    '2 weeks' => '',
    '3 months' => '',
    '6 months' => '',
    '<strong>Confirm</strong> icon deletion' => '',
    '<strong>Confirm</strong> image deletion' => '',
    '<strong>Maintenance</strong> Mode' => '',
    '<strong>Warning:</strong> All users will be immediately logged out, except admins.' => '',
    'APC(u)' => '',
    'Access Token' => '',
    'Access token is not provided yet.' => '',
    'Activate' => '',
    'Activate maintenance mode and disable access to the platform for non-admin users?<br><br>' => '',
    'Add OEmbed provider' => '',
    'Add custom info text for maintenance mode. Displayed on the login page.' => '',
    'Add new provider' => '',
    'Advanced Settings' => '',
    'Allow Self-Signed Certificates?' => '',
    'Allowed file extensions' => '',
    'Alphabetical' => '',
    'Appearance Settings' => '',
    'Auto format based on user language - Example: {example}' => '',
    'Back to overview' => '',
    'Base URL' => '',
    'Cache Backend' => '',
    'Comma separated list. Leave empty to allow all.' => '',
    'Could not send test email.' => '',
    'Currently no provider active!' => '',
    'Currently there are {count} records in the database dating from {dating}.' => '',
    'Dashboard' => '',
    'Date input format' => '',
    'Deactivate' => '',
    'Deactivate maintenance mode and enable all users to access the platform again?' => '',
    'Default Expire Time (in seconds)' => '',
    'Default Timezone' => '',
    'Default language' => '',
    'Default pagination size (Entries per page)' => '',
    'Default stream content order' => '',
    'Delete' => '',
    'Display Name (Format)' => '',
    'Dropdown space order' => '',
    'E-Mail' => '',
    'E-Mail reply-to' => '',
    'E-Mail sender address' => '',
    'E-Mail sender name' => '',
    'E.g. http://example.com/humhub' => '',
    'Edit OEmbed provider' => '',
    'Embedded content requires the user\'s consent to be loaded' => '',
    'Enable maintenance mode' => '',
    'Enable user friendship system' => '',
    'Enabled' => '',
    'Enabled OEmbed providers' => '',
    'Encryption' => '',
    'Endpoint Url' => '',
    'Exclude media files from stream attachment list' => '',
    'File' => '',
    'Firstname Lastname (e.g. John Doe)' => '',
    'Fixed format (dd/mm/yyyy) - Example: {example}' => '',
    'Friendship' => '',
    'General' => '',
    'General Settings' => '',
    'HTML tracking code' => '',
    'Here you can configurate the registration behaviour and additinal user settings of your social network.' => '',
    'Here you can configure basic settings of your social network.' => '',
    'Horizontal scrolling images on a mobile device' => '',
    'Icon upload' => '',
    'Last visit' => '',
    'Logo upload' => '',
    'Mail Transport Type' => '',
    'Maintenance mode' => '',
    'Maximum allowed age for logs.' => '',
    'Maximum upload file size (in MB)' => '',
    'Mobile appearance' => '',
    'Name of the application' => '',
    'No Proxy Hosts' => '',
    'No caching' => '',
    'Notification Settings' => '',
    'Old logs can significantly increase the size of your database while providing little information.' => '',
    'Optional. Default reply address for system emails like notifications.' => '',
    'PHP APC(u) Extension missing - Type not available!' => '',
    'PHP reported a maximum of {maxUploadSize} MB' => '',
    'Password' => '',
    'Port' => '',
    'Port number' => '',
    'Prevent client caching of following scripts' => '',
    'Provider Name' => '',
    'Redis' => '',
    'Regular expression by which the link match will be checked.' => '',
    'Reported database time: {dateTime}' => '',
    'SMTP Options' => '',
    'Save & Flush Caches' => '',
    'Save & Test' => '',
    'Saved' => '',
    'Saved and flushed cache' => '',
    'Saved and sent test email to: {address}' => '',
    'Server' => '',
    'Server Timezone' => '',
    'Show introduction tour for new users' => '',
    'Show user profile post form on dashboard' => '',
    'Sort by creation date' => '',
    'Sort by update date' => '',
    'Test message' => '',
    'Theme' => '',
    'These settings refer to advanced topics of your social network.' => '',
    'These settings refer to the appearance of your social network.' => '',
    'Url Pattern' => '',
    'Use %url% as placeholder for URL. Format needs to be JSON. (e.g. http://www.youtube.com/oembed?url=%url%&format=json)' => '',
    'Use X-Sendfile for File Downloads' => '',
    'Use the default swipe to show sidebar on a mobile device' => '',
    'User' => '',
    'User Settings' => '',
    'Username' => '',
    'Username (e.g. john)' => '',
    'You can add a statistic code snippet (HTML) - which will be added to all rendered pages.' => '',
    'You\'re using no icon at the moment. Upload your logo now.' => '',
    'You\'re using no logo at the moment. Upload your logo now.' => '',
    'never' => '',
];

==> humhub-1.15.0-beta.2.tar.gz: humhub-1.15.0-beta.2/protected/humhub/modules/admin/messages/zh-TW/settings.php <==
<?php

return [
    '1 month' => '1個月',
    '1 week' => '1周',
    '1 year' => '1年',
    '2 weeks' => '2周',
    '3 months' => '3個月',
    '6 months' => '6個月',
    '<strong>Confirm</strong> icon deletion' => '<strong>確認</strong>刪除標誌',
    '<strong>Confirm</strong> image deletion' => '<strong>確認</strong>刪除圖像',
    '<strong>Maintenance</strong> Mode' => '<strong>維護</strong> 模式',
    'Activate' => '啟用',
    'Dashboard' => '儀表板',
    'Default Timezone' => '預設時區',
    'Default language' => '預設語言',
    'Delete' => '刪除帳戶',
    'E-Mail' => 'E-mail',
    'Enabled' => '啟用',
    'Friendship' => '添加朋友',
    'General' => '一般資訊',
    'General Settings' => '一般設定',
    'Maintenance mode' => '維護模式',
    'Mobile appearance' => '手機版外觀',
    'Name of the application' => '應用程式名稱',
    'Notification Settings' => '通知設定',
    'Password' => '密碼',
    'Port' => 'Port',
    'Save' => '儲存',
    'Save & Flush Caches' => '儲存並清理快取',
    'Save & Test' => '儲存並測試',
    'Saved' => '已儲存',
    'Saved and flushed cache' => '已儲存且快取已清理',
    'Server' => '伺服器',
    'Server Timezone' => '伺服器時區',
    'Theme' => '佈景主題',
    'User' => '用户',
    'User Display Name' => '用戶顯示名稱',
    'Username' => '使用者名稱',
    'never' => '從未',
    '<strong>Warning:</strong> All users will be immediately logged out, except admins.' => '',
    'Access Token' => '',
    'Access token is not provided yet.' => '',
    'Activate maintenance mode and disable access to the platform for non-admin users?<br><br>' => '',
    'Add OEmbed provider' => '',
    'Add custom info text for maintenance mode. Displayed on the login page.' => '',
    'Add new provider' => '',
    'Advanced Settings' => '',
    'Allow Self-Signed Certificates?' => '',
    'Allowed file extensions' => '',
    'Alphabetical' => '',
    'Appearance Settings' => '',
    'Auto format based on user language - Example: {example}' => '',
    'Back to overview' => '',
    'Base URL' => '',
    'Comma separated list. Leave empty to allow all.' => '',
    'Configuration (Use settings from configuration file)' => '',
    'Could not send test email.' => '',
    'Currently no provider active!' => '',
    'Currently there are {count} records in the database dating from {dating}.' => '',
    'Custom DSN' => '',
    'DSN' => '',
    'DSN Examples:' => '',
    'Date input format' => '',
    'Deactivate' => '',
    'Deactivate maintenance mode and enable all users to access the platform again?' => '',
    'Default pagination size (Entries per page)' => '',
    'Default stream content order' => '',
    'Dropdown space order' => '',
    'E-Mail reply-to' => '',
    'E-Mail sender address' => '',
    'E-Mail sender name' => '',
    'E.g. http://example.com/humhub' => '',
    'Edit OEmbed provider' => '',
    'Embedded content requires the user\'s consent to be loaded' => '',
    'Enable maintenance mode' => '',
    'Enable user friendship system' => '',
    'Enabled OEmbed providers' => '',
    'Endpoint Url' => '',
    'Exclude media files from stream attachment list' => '',
    'Firstname Lastname (e.g. John Doe)' => '',
    'Fixed format (dd/mm/yyyy) - Example: {example}' => '',
    'HTML tracking code' => '',
    'Here you can configurate the registration behaviour and additinal user settings of your social network.' => '',
    'Here you can configure basic settings of your social network.' => '',
    'Horizontal scrolling images on a mobile device' => '',
    'Icon upload' => '',
    'Inserted script tags must contain a nonce. e.g. {code}' => '',
    'Last visit' => '',
    'Logo upload' => '',
    'Mail Transport Type' => '',
    'Maximum allowed age for logs.' => '',
    'Maximum upload file size (in MB)' => '',
    'No Delivery (Debug Mode, Save as file)' => '',
    'No Proxy Hosts' => '',
    'Old logs can significantly increase the size of your database while providing little information.' => '',
    'Optional. Default reply address for system emails like notifications.' => '',
    'PHP (Use settings of php.ini file)' => '',
    'PHP reported a maximum of {maxUploadSize} MB' => '',
    'Port number' => '',
    'Provider Name' => '',
    'Regular expression by which the link match will be checked.' => '',
    'Reported database time: {dateTime}' => '',
    'Saved and sent test email to: {address}' => '',
    'Show introduction tour for new users' => '',
    'Show user profile post form on dashboard' => '',
    'Sort by creation date' => '',
    'Sort by update date' => '',
    'Test message' => '',
    'These settings refer to advanced topics of your social network.' => '',
    'These settings refer to the appearance of your social network.' => '',
    'Url Pattern' => '',
    'Use %url% as placeholder for URL. Format needs to be JSON. (e.g. http://www.youtube.com/oembed?url=%url%&format=json)' => '',
    'Use SMTPS' => '',
    'Use X-Sendfile for File Downloads' => '',
    'User Display Name Subtitle' => '',
    'User Settings' => '',
    'Username (e.g. john)' => '',
    'You can add a statistic code snippet (HTML) - which will be added to all rendered pages.' => '',
    'You can find more configuration options here:' => '',
    'You\'re using no icon at the moment. Upload your logo now.' => '',
    'You\'re using no logo at the moment. Upload your logo now.' => '',
    'e.g. 25 (for SMTP) or 465 (for SMTPS)' => '',
    'e.g. localhost' => '',
    'e.g. smtps://user:pass@smtp.example.com:port' => '',
];
